@@ -56,11 +56,11 @@ Web::MREST - Minimalistic REST server
 
 =head1 VERSION
 
-Version 0.263
+Version 0.268
 
 =cut
 
-our $VERSION = '0.263';
+our $VERSION = '0.268';
 
 
 =head2 Development status
@@ -1372,7 +1372,8 @@ sub init {
             $target = File::ShareDir::dist_dir( $ARGS{'distro'} );
             $status = $CELL->load( sitedir => $target );
             return $status if $status->not_ok;
-        } elsif ( my $sitedir_target = $ARGS{'sitedir'} ) {
+        }
+        if ( my $sitedir_target = $ARGS{'sitedir'} ) {
             if ( -d $sitedir_target ) {
                 $status = $CELL->load( sitedir => $sitedir_target );
                 return $status if $status->not_ok;
@@ -1380,7 +1381,8 @@ sub init {
                 $log->warn( 'Web::MREST::init() says sitedir argument given, but it is not a directory: ' .
                     Dumper( $sitedir_target ) );
             }
-        } elsif ( $ARGS{'hashref'} ) {
+        }
+        if ( $ARGS{'hashref'} ) {
             my $count = 0;
             foreach my $key ( keys %{ $ARGS{'hashref'} } ) {
                 $meta->set( $key, $ARGS{'hashref'}->{$key} );
