@@ -65,11 +65,11 @@ Web::MREST::Test - Test helper functions
 
 =head1 VERSION
 
-Version 0.263
+Version 0.268
 
 =cut
 
-our $VERSION = '0.263';
+our $VERSION = '0.268';
 
 
 
@@ -127,6 +127,7 @@ unit. Takes a PARAMHASH with two optional parameters:
 
 sub initialize_unit {
     my %ARGS = @_;
+    diag( "Initializing unit " . (caller)[1] . " with arguments " . Dumper( \%ARGS ) );
     my $class = $ARGS{'class'} || undef;
     my %init_options = $ARGS{'sitedir'}
         ? ( 'sitedir' => $ARGS{'sitedir'} )
@@ -137,12 +138,15 @@ sub initialize_unit {
     unlink $log_file_spec;
     Log::Any::Adapter->set( 'File', $log_file_spec );
     $log->init( ident => 'MREST_UNIT_TEST' );
-    $log->info( "Initializing unit " . (caller)[1] );
 
     # load configuration parameters
     my $status = Web::MREST::init( %init_options );
     is( $status->level, 'OK' );
 
+    note( 'check that site configuration parameters were loaded' );
+    is_deeply(  $site->MREST_SUPPORTED_CONTENT_TYPES, [ 'application/json' ],
+        'configuration parameters loaded?' );
+
     # set debug mode
     $log->debug_mode( $site->MREST_DEBUG_MODE );
 
